function plotMeanFreePathAndVapourPressureVsTemp(TemperatureinCelsius)
    
    TemperatureinKelvin = TemperatureinCelsius + 273.15;
    
    Dy164VapourPressure  = 133.322*exp(11.4103-2.3785e+04./(-219.4821+TemperatureinKelvin)); % Vapor Pressure Dysprosium for the given oven temperature        
    MeanFreepath  = (Helper.PhysicsConstants.BoltzmannConstant*TemperatureinKelvin)./(sqrt(2) * ( pi * (2*281e-12)^2) * Dy164VapourPressure);      %free path at above tempeture
    
    f_h = Helper.getFigureByTag('Dysprosium Gas Properties');
    set(groot,'CurrentFigure',f_h);
    a_h = get(f_h, 'CurrentAxes');
    if ~isempty(get(a_h, 'Children')) 
        clf(f_h);
    end
    f_h.Name  = 'Dysprosium Gas Properties';
    f_h.Units = 'pixels';
    
    set(0,'units','pixels');
    screensize = get(0,'ScreenSize');
    f_h.Position = [[screensize(3)/3.5 screensize(4)/3.5] 750 600];
    
    yyaxis left
    semilogy(TemperatureinCelsius, Dy164VapourPressure, 'Color', '#0071BB', 'Linewidth',1.5);
    hYLabel_1 = ylabel('Vapor Pressure (mbar)');
    yyaxis right
    semilogy(TemperatureinCelsius, MeanFreepath.*1000,  'Color', '#36B449', 'Linewidth',1.5)
    hYLabel_2 = ylabel('Mean Free Path (mm)');
    
    hXLabel   = xlabel('Temperature (℃)');
    
    ax = gca;
    ax.YAxis(1).Color = '#0071BB';
    ax.YAxis(2).Color = '#36B449';

    hTitle    = sgtitle('^{164}Dy Gas');

    set([hXLabel, hYLabel_1, hYLabel_2]  , ...
        'FontSize'   , 14          );
    set( hTitle                    , ...
        'FontSize'   , 18          );
    
    grid on
    Helper.bringFiguresWithTagInForeground();
end
